# Erk Public Content

Content intended for external publication, including articles, writing guides, and learning series.

## Contents

- [Style Guides](style-guides/) - Writing style guides (including schrockn-style)
- [Agentic Programming](agentic-programming/) - Philosophy and articles about agentic programming
- [30 Days Series](30-days-series/) - 30 Days of Agentic Programming learning series

## Purpose

This folder contains content that may be published externally as blog posts, documentation, or educational material.
